cumulusci.tasks.release\_notes package
======================================

Subpackages
-----------

.. toctree::

    cumulusci.tasks.release_notes.tests

Submodules
----------

cumulusci.tasks.release\_notes.exceptions module
------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.generator module
-----------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.generator
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.parser module
--------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.parser
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.provider module
----------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.provider
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.task module
------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.task
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.release_notes
    :members:
    :undoc-members:
    :show-inheritance:
